@@ -178,172 +178,157 @@ void
 install_new_procedures (void)
 {
   /* installing general procedures */
-  gh_new_procedure ("fh-load", ex_load, 1, 0, 0);
+  scm_c_define_gsubr ("fh-load", 1, 0, 0, ex_load);
   /* this way you call me
      (fh-load "aliases.scm")
   */
 
-  gh_new_procedure ("fh-send-message", ex_send_message, 2, 0, 0);
+  scm_c_define_gsubr ("fh-send-message", 2, 0, 0, ex_send_message);
   /* this way you call me
      (fh-send-message "hello gnu")
   */
 
-  gh_new_procedure ("fh-send-message-no-hook", 
-		    ex_send_message_no_hook, 2, 0, 0);
+  scm_c_define_gsubr ("fh-send-message-no-hook", 2, 0, 0, ex_send_message);
   /* this way you call me
      (fh-send-message-no-hook "hello gnu")
   */
 
-  gh_new_procedure ("fh-set-current-target-buddy!",
-		    ex_set_current_target_buddy_x, 2, 0, 0);
+  scm_c_define_gsubr ("fh-set-current-target-buddy!", 2, 0, 0, ex_set_current_target_buddy_x);
   /* this way you call me
      (fh-set-current-target-buddy! "my_friend")
   */
 
-  gh_new_procedure ("fh-register-command!",
-		    ex_register_command_x, 1, 0, 0);
+  scm_c_define_gsubr ("fh-register-command!", 1, 0, 0, ex_register_command_x);
   /* this way you call me
      (fh-register-command  "/ping")
   */
 
-  gh_new_procedure ("fh-unregister-command!",
-		    ex_unregister_command_x, 1, 0, 0);
+  scm_c_define_gsubr ("fh-unregister-command!", 1, 0, 0, ex_unregister_command_x);
   /* this way you call me
      (fh-unregister-command  "/ping")
   */
 
-  gh_new_procedure ("fh-version", ex_version, 0, 0, 0);
+  scm_c_define_gsubr ("fh-version", 0, 0, 0, ex_version);
   /* this way you call me
      (display (fh-version))
   */
 
-  gh_new_procedure ("fh-display", ex_display, 1, 0, 0);
+  scm_c_define_gsubr ("fh-display", 1, 0, 0, ex_display);
   /* this way you call me
      (fh-display "Hello GNU")
   */
 
-  gh_new_procedure ("fh-get-buddy-list",
-		    ex_get_buddy_list, 0, 0, 0);
+  scm_c_define_gsubr ("fh-get-buddy-list", 0, 0, 0, ex_get_buddy_list);
   /* this way you call me
      (define buddy_list (fh-get-buddy-list))
   */
 
-  gh_new_procedure ("fh-add-buddy",
-		    ex_add_buddy, 1, 1, 0);
+  scm_c_define_gsubr ("fh-add-buddy", 1, 1, 0, ex_add_buddy);
     
   /* this way you call me
      (fh-add-buddy "balugi" "GNU")
   */
 
   /* installing configuration procedures */
-  gh_new_procedure ("fh-bell!", ex_bell, 0, 0, 0);
+  scm_c_define_gsubr ("fh-bell!", 0, 0, 0, ex_bell);
   /* this way you call me
      (fh-bell!)
   */
 
-  gh_new_procedure ("fh-toggle!", ex_toggle_x, 1, 0, 0);
+  scm_c_define_gsubr ("fh-toggle!", 1, 0, 0, ex_toggle_x);
   /* this way you call me
      (fh-bell-toggle! 'bell)
   */
 
-  gh_new_procedure ("fh-get-home-dir", ex_get_home_dir, 0, 0, 0);
+  scm_c_define_gsubr ("fh-get-home-dir", 0, 0, 0, ex_get_home_dir);
   /* this way you call me
      (display (fh-get-home-dir))
   */
 
-  gh_new_procedure ("fh-get-config-dir", 
-		    ex_get_config_dir, 0, 0, 0);
+  scm_c_define_gsubr ("fh-get-config-dir", 0, 0, 0, ex_get_config_dir);
   /* this way you call me
      (display (fh-get-config-dir))
   */
 
-  gh_new_procedure ("fh-get-config-filename",
-		    ex_get_config_filename, 0, 0, 0);
+  scm_c_define_gsubr ("fh-get-config-filename", 0, 0, 0, ex_get_config_filename);
   /* this way you call me
      (display (fh-get-config-filename)
   */
 
-  gh_new_procedure ("fh-get-download-filename",
-		    ex_get_download_filename, 0, 0, 0);
+  scm_c_define_gsubr ("fh-get-download-filename", 0, 0, 0, ex_get_download_filename);
   /* this way you call me
      (display (fh-get-downlaod-filename)
   */
 
-  gh_new_procedure ("fh-get-global-extensions-directory",
-		    ex_get_global_extensions_directory, 0, 0, 0);
+  scm_c_define_gsubr ("fh-get-global-extensions-directory", 0, 0, 0, ex_get_global_extensions_directory);
   /* this way you call me
      (display (fh-get-global-extensions-directory))
   */
 
-  gh_new_procedure ("fh-get-local-extensions-directory",
-		    ex_get_local_extensions_directory, 0, 0, 0);
+  scm_c_define_gsubr ("fh-get-local-extensions-directory", 0, 0, 0, ex_get_local_extensions_directory);
   /* this way you call me
      (display (fh-get-local-extensions-directory))
   */
 
-  gh_new_procedure ("fh-get-default-login-id",
-		    ex_get_default_login_id, 0, 0, 0);
+  scm_c_define_gsubr ("fh-get-default-login-id", 0, 0, 0, ex_get_default_login_id);
   /* this way you call me
      (display (fh-get-login-id))
   */
 
-  gh_new_procedure ("fh-set-default-login-id!",
-		    ex_set_default_login_id_x, 1, 0, 0);
+  scm_c_define_gsubr ("fh-set-default-login-id!", 1, 0, 0, ex_set_default_login_id_x);
   /* this way you call me
      (fh-set-login-id! "abindian")
   */
 
-  gh_new_procedure ("fh-set-default-password!",
-		    ex_set_default_password_x, 1, 0, 0);
+  scm_c_define_gsubr ("fh-set-default-password!", 1, 0, 0, ex_set_default_password_x);
   /* this way you call me
      (fh-set-login-id! "press_enter")
   */
 
-  gh_new_procedure ("fh-set-default-status!",
-		    ex_set_default_status_x, 1, 0, 0);
+  scm_c_define_gsubr ("fh-set-default-status!", 1, 0, 0, ex_set_default_status_x);
   /* this way you call me
      ;; default to invisible mode
      (fh-set-status! 12)
   */
 
-  gh_new_procedure ("fh-set-prompt!", ex_set_prompt_x, 1, 0, 0);
+  scm_c_define_gsubr ("fh-set-prompt!", 1, 0, 0, ex_set_prompt_x);
   /* this way you call me
      ;; set prompt string
      (fh-set-prompt! "~qp~> ")
   */
 
   /* installing hook related procedures */
-  gh_new_procedure ("fh-hook-return", ex_hook_return, 0, 0, 0);
+  scm_c_define_gsubr ("fh-hook-return", 0, 0, 0, ex_hook_return);
   /* this way you call me
      (fh-hook-return)
   */
 
   /* installing hook related procedures */
-  gh_new_procedure ("fh-quit", ex_fh_quit, 0, 0, 0);
+  scm_c_define_gsubr ("fh-quit", 0, 0, 0, ex_fh_quit);
   /* this way you call me
      (fh-quit)
   */
 
   /* installing hook related procedures */
-  gh_new_procedure ("fh-logoff", ex_fh_logoff, 0, 0, 0);
+  scm_c_define_gsubr ("fh-logoff", 0, 0, 0, ex_fh_logoff);
   /* this way you call me
      (fh-logoff)
   */
 
   /* add new word for dictionary autocomplete */
-  gh_new_procedure ("fh-dict-add-word!", ex_fh_dict_add_word, 1, 0, 0);
+  scm_c_define_gsubr ("fh-dict-add-word!", 1, 0, 0, ex_fh_dict_add_word);
   /* this way you call me
    * (fh-dict-add-word! "newbigword")
    */
 
   /* add new word for dictionary autocomplete in pre sorted sequence */
-  gh_new_procedure ("fh-dict-add-word-sorted!", ex_fh_dict_add_word_sorted, 1, 0, 0);
+  scm_c_define_gsubr ("fh-dict-add-word-sorted!", 1, 0, 0, ex_fh_dict_add_word_sorted);
   /* this way you call me
    * (fh-dict-add-word-sorted! "newbigword")
    */
 
   /* delete word from automplete dictionary */
-  gh_new_procedure ("fh-dict-del-word!", ex_fh_dict_del_word, 1, 0, 0);
+  scm_c_define_gsubr ("fh-dict-del-word!", 1, 0, 0, ex_fh_dict_del_word);
   /* this way you call me
    * (fh-dict-del-word! "easy")
    */
