@@ -177,7 +177,7 @@ get_token_with_strdelim (char **line, char *delim)
 
   token = (char *) malloc (sizeof (char) * (token_length + 1));
   strncpy (token, *line, token_length);
-  token[token_length] = (char) NULL;
+  token[token_length] = 0;
   *line = tmp_str;
 
   return token;
@@ -201,7 +201,7 @@ get_token_with_strdelim_i (char **line, char *delim)
 
   token = (char *) malloc (sizeof (char) * (token_length + 1));
   strncpy (token, *line, token_length);
-  token[token_length] = (char) NULL;
+  token[token_length] = 0;
   *line = tmp_str;
 
   return token;
@@ -338,18 +338,9 @@ get_utc_time (char *time_secs)
 void
 show_version (void)
 {
-#ifdef VERSION
-  printf ("GNU Messenger %s for Yahoo\n", VERSION);
-#else
-  printf ("GNU Messenger for Yahoo%s\n");
-#endif
+  printf ("Freehoo %s\n", VERSION);
   printf("Copyright (C) 2003 FreeHoo Core Team.\n");
-
-  fputs ("GNU Yahoo Messenger comes with ABSOLUTELY NO WARRANTY.\n"
-	 "You may redistribute copies of GNU Yahoo\n"
-	 "under the terms of the GNU General Public License.\n"
-	 "For more information about these matters, see the file"
-	 "named COPYING.\n", stdout);
+  fputs ("Freehoo comes with ABSOLUTELY NO WARRANTY. You may redistribute copies of Freehoo under the terms of the GNU General Public License v2 or later. For more information about these matters, see the file named COPYING.\n", stdout);
 }
 
 char *
@@ -455,7 +446,7 @@ fh_load (char *filename)
 
   if (stat (filename, &buf) == 0)
     {
-      gh_load (filename);
+      scm_c_primitive_load (filename);
       return;
     }
 
@@ -466,7 +457,7 @@ fh_load (char *filename)
   if (stat (extension_filepath, &buf) == 0)
     {
       /* gh_eval_file_with_standard_handler (extension_filepath); */
-      gh_load (extension_filepath);
+      scm_c_primitive_load (extension_filepath);
       return;
     }
   free (extension_filepath);
@@ -478,7 +469,7 @@ fh_load (char *filename)
 	   filename);
   if (stat (extension_filepath, &buf) == 0)
     {
-      gh_load (extension_filepath);
+      scm_c_primitive_load (extension_filepath);
       return;
     }
 }
