@@ -30,7 +30,6 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#include <glib.h>
 #include <yahoo2.h>
 #include <regex.h>
 
@@ -196,9 +195,9 @@ set_current_status_custom_message (char *current_status_custom_message_value)
 void
 register_command (SCM command)
 {
-  if (gh_list_p (dynamic_commands) != 1)
+  if (scm_is_true (scm_list_p (dynamic_commands)) != 1)
     {// not a list
-      dynamic_commands = gh_list (command, SCM_UNDEFINED);
+      dynamic_commands = scm_list_n (command, SCM_UNDEFINED);
       gh_define (EX_DYNAMIC_COMMANDS, dynamic_commands);
 
     }
@@ -206,7 +205,7 @@ register_command (SCM command)
     {
       dynamic_commands =
         gh_append2 (dynamic_commands,
-                    gh_list (command, SCM_UNDEFINED));
+                    scm_list_n (command, SCM_UNDEFINED));
       gh_define (EX_DYNAMIC_COMMANDS, dynamic_commands);
     }
 }
@@ -220,22 +219,21 @@ unregister_command (SCM command)
   int dynamic_command_index = 0;
   int dynamic_commands_count = 0;
 
-  if (gh_list_p (dynamic_commands) != 1)
+  if (scm_is_true (scm_list_p (dynamic_commands)) != 1)
     return;
   
-  dynamic_command = gh_scm2newstr (command, NULL);
+  dynamic_command = scm_to_locale_string (command);
 
   if (dynamic_command == NULL)
     return;
 
-  dynamic_commands_count = gh_length (dynamic_commands);
+  dynamic_commands_count = scm_to_size_t (scm_length (dynamic_commands));
 
   while (dynamic_command_index < dynamic_commands_count)
     {
-      tmp_scm = gh_list_ref (dynamic_commands, gh_ulong2scm (dynamic_command_index++));
-      dynamic_cmd = gh_scm2newstr (gh_list_ref (tmp_scm,
-						gh_ulong2scm (0)),
-				   NULL);
+      tmp_scm = scm_list_ref (dynamic_commands, scm_from_ulong (dynamic_command_index++));
+      dynamic_cmd = scm_to_locale_string (scm_list_ref (tmp_scm,
+							scm_from_ulong (0)));
       if (dynamic_cmd && strcasecmp (dynamic_cmd, dynamic_command) == 0)
 	{
 	  dynamic_commands = scm_delete (tmp_scm, dynamic_commands);
@@ -427,16 +425,16 @@ command_generator (const char *text, int state)
     }
 
   if(complete_cmd) {
-    if (gh_list_p (dynamic_commands))
+    if (scm_is_true (scm_list_p (dynamic_commands)))
       {
-	dynamic_commands_count = gh_length (dynamic_commands);
+	dynamic_commands_count = scm_to_size_t (scm_length (dynamic_commands));
 	while (dynamic_cmd_index < dynamic_commands_count)
 	  {
 	    dynamic_command = 
-	      gh_scm2newstr (gh_list_ref (gh_list_ref (dynamic_commands, 
-						       gh_ulong2scm (dynamic_cmd_index++)),
-					  gh_ulong2scm (0)),
-			     NULL);
+	      scm_to_locale_string (scm_list_ref 
+				    (scm_list_ref (dynamic_commands, 
+						   scm_from_ulong (dynamic_cmd_index++)),
+				     scm_from_ulong (0)));
 	    if (dynamic_command && strncasecmp (dynamic_command, text, len) == 0)
 	      return strdup (dynamic_command);
 	  }
@@ -533,7 +531,7 @@ interpreter (char *line)
 
     }
 
-  /* Preverse history before extracting the command out of it. We need
+  /* reverse history before extracting the command out of it. We need
   it to add_history later on. -- Anand Babu <ab@gnu.org.in> */
   history_line = strdup (line);
   command = get_token (&line);
@@ -754,14 +752,15 @@ interpreter (char *line)
       return;
     }
   
-  if (gh_list_p (dynamic_commands) == 1)
+  if (scm_is_true (scm_list_p (dynamic_commands)) == 1)
     {
-      for (i=0; i < gh_length (dynamic_commands); i++)
+      for (i=0; i < scm_to_size_t (scm_length (dynamic_commands)); i++)
 	{
-	  dynamic_command = gh_scm2newstr (gh_list_ref (gh_list_ref (dynamic_commands, 
-								     gh_ulong2scm (i)), 
-							gh_ulong2scm (0)),
-					   NULL);
+	  dynamic_command = 
+	    scm_to_locale_string (scm_list_ref 
+				  (scm_list_ref (dynamic_commands, 
+						 scm_from_ulong (i)), 
+				   scm_from_ulong (0)));
 	  if (dynamic_command && strcasecmp (dynamic_command, command) == 0)
 	    {
 	      command_dynamic_commands (dynamic_command, line);
@@ -952,25 +951,23 @@ command_show_help (char *line)
      "\t- my_command really freaks ;-)\n");
      }
   */
-  if (gh_list_p (dynamic_commands) == 1)
+  if (scm_is_true (scm_list_p (dynamic_commands)) == 1)
     {
       int i;
       SCM tmp_scm;
       char *dynamic_syntax = NULL;
       
-      for (i=0; i < gh_length (dynamic_commands); i++)
+      for (i=0; i < scm_to_size_t (scm_length (dynamic_commands)); i++)
 	{
 	  dynamic_syntax = NULL;
 	  tmp_scm = 
-	    gh_list_ref (dynamic_commands, gh_ulong2scm (i));
+	    scm_list_ref (dynamic_commands, scm_from_ulong (i));
 	  dynamic_command = 
-	    gh_scm2newstr (gh_list_ref (tmp_scm, gh_ulong2scm (0)),
-			   NULL);
+	    scm_to_locale_string (scm_list_ref (tmp_scm, scm_from_ulong (0)));
 	  if (all || (strcasecmp (command, dynamic_command) == 0))
 	    {
 	      dynamic_syntax = 
-		gh_scm2newstr (gh_list_ref (tmp_scm, gh_ulong2scm (1)),
-			       NULL);
+		scm_to_locale_string (scm_list_ref (tmp_scm, scm_from_ulong (1)));
 	      if (dynamic_syntax != NULL)
 		printf ("%s\n", dynamic_syntax);
 	    }
