@@ -1,5 +1,5 @@
 /* 
-   scm-procedures.c: gnu messenger procedures that are exported to
+   scm-procedures.c: messenger procedures that are exported to
    guile environment
    
    This program is free software; you can redistribute it and/or
@@ -22,7 +22,6 @@
 #include <readline/readline.h>
 #include <libguile.h>
 #include <assert.h>
-#include <glib.h>
 #include <yahoo2.h>
 
 #include <sys/stat.h>
