@@ -32,8 +32,6 @@
 #include <guile/gh.h>
 #include <readline/readline.h>
 
-#include <glib.h>
-
 #include "freehoo.h"
 #include "interpreter.h"
 #include "yahoo-adapter.h"
@@ -85,8 +83,8 @@ send_message (char *to, char *message)
   
   set_hook_return (0);
   scm_run_hook (get_message_send_hook (),
-		gh_list (gh_str02scm (to),
-			 gh_str02scm (message),
+		scm_list_n (scm_from_locale_string (to),
+			 scm_from_locale_string (message),
 			 SCM_UNDEFINED));
   
   if (get_hook_return () == 1)
