@@ -243,7 +243,7 @@ get_time ()
   return (ct.tv_sec * 1E3 + ct.tv_usec / 1E3);
 }
 
-static int
+int
 yahoo_ping_timeout_callback ()
 {
  /*  PRINTF_MESSAGE ("Sending a keep alive message\n"); */
@@ -252,7 +252,7 @@ yahoo_ping_timeout_callback ()
   return 1;
 }
 
-static int
+int
 yahoo_webcam_timeout_callback (int id)
 {
   static unsigned image_num = 0;
@@ -643,8 +643,8 @@ ext_yahoo_got_im (int id, char *who, char *msg, long tm, int stat, int utf8)
   // invoke fh-message-receive-hook
   set_hook_return (0);
   scm_run_hook (get_message_receive_hook (),
-                gh_list (gh_str02scm (who),
-                         gh_str02scm (msg),
+                scm_list_n (scm_from_locale_string (who),
+                         scm_from_locale_string (msg),
                          SCM_UNDEFINED));
   if (get_hook_return () == 1)
     return;
@@ -692,8 +692,8 @@ ext_yahoo_contact_added (int id, char *myid, char *who, char *msg)
   // invoke fh-contact-added-hook
   set_hook_return (0);
   scm_run_hook (get_contact_added_hook (),
-                gh_list (gh_str02scm (who),
-                         gh_str02scm (buf),
+                scm_list_n (scm_from_locale_string (who),
+                         scm_from_locale_string (buf),
                          SCM_UNDEFINED));
   if (get_hook_return () == 1)
     return;
@@ -742,8 +742,8 @@ ext_yahoo_mail_notify (int id, char *from, char *subj, int cnt)
 
       /* Mail notify hook */
       scm_run_hook (get_mail_notify_hook (),
-		    gh_list (gh_str02scm (from),
-			     gh_str02scm (subj),
+		    scm_list_n (scm_from_locale_string (from),
+			     scm_from_locale_string (subj),
 			     SCM_UNDEFINED));
     }
 
@@ -944,7 +944,7 @@ ext_yahoo_login (yahoo_local_account * ylad, int login_mode)
   yahoo_login (ylad->id, login_mode);
 
   // invoke fh-login-post-hook
-  scm_run_hook (get_login_post_hook (), gh_list (SCM_UNDEFINED));
+  scm_run_hook (get_login_post_hook (), scm_list_n (SCM_UNDEFINED));
 
 /*	if (ylad->id <= 0) {
 		print_message(("Could not connect to Yahoo server.  Please verify that you are connected to the net and the pager host and port are correctly entered."));
